aboutsummaryrefslogtreecommitdiff
path: root/bdep/init.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'bdep/init.hxx')
-rw-r--r--bdep/init.hxx6
1 files changed, 4 insertions, 2 deletions
diff --git a/bdep/init.hxx b/bdep/init.hxx
index 8569f91..0aec927 100644
--- a/bdep/init.hxx
+++ b/bdep/init.hxx
@@ -27,7 +27,8 @@ namespace bdep
bool config_create_specified);
// Initialize each package in each configuration skipping those that are
// already initialized. Then synchronize each configuration.
//
void
cmd_init (const common_options&,
@@ -35,7 +36,8 @@ namespace bdep
database&,
const configurations&,
const package_locations&,
- const strings& pkg_args);
+ const strings& pkg_args,
+ bool sync = true);
int
cmd_init (const cmd_init_options&, cli::group_scanner& args);
@@ -27,7 +27,8 @@ namespace bdep
bool config_create_specified);
// Initialize each package in each configuration skipping those that are
- // already initialized. Then synchronize each configuration.
+ // already initialized. Then synchronize each configuration unless sync
+ // is false.
//
void